pub enum TerminalProgram {
Show 18 variants
Dumb,
Ansi,
ITerm2,
Terminology,
Kitty,
WezTerm,
VSCode,
Ghostty,
Alacritty,
Foot,
Konsole,
AppleTerminal,
Warp,
Rio,
Hyper,
Contour,
Mlterm,
WindowsTerminal,
}Expand description
A terminal application.
Variants
Dumb
A dumb terminal which does not support any formatting.
Ansi
A plain ANSI terminal which supports only standard ANSI formatting.
ITerm2
iTerm2 — https://www.iterm2.com.
Terminology
Terminology — http://terminolo.gy.
Kitty
Kitty — https://sw.kovidgoyal.net/kitty/.
WezTerm
WezTerm — https://wezfurlong.org/wezterm/.
VSCode
The built-in terminal in VSCode (since 1.80, iTerm2 image protocol).
Ghostty
Ghostty — https://mitchellh.com/ghostty.
Alacritty
Alacritty — ANSI + OSC 8 hyperlinks.
Foot
Foot, Wayland terminal — ANSI + OSC 8 + Sixel (when the feature lands).
Konsole
KDE Konsole — ANSI + OSC 8.
AppleTerminal
Apple’s Terminal.app — ANSI only on older macOS; OSC 8 on macOS 15+.
Warp
Warp — https://warp.dev.
Rio
Rio — https://raphamorim.io/rio/. Supports Kitty graphics.
Hyper
Hyper (Electron-based) — ANSI only.
Contour
Contour — ANSI + OSC 8 (Sixel when the feature lands).
Mlterm
mlterm — ANSI + Sixel (when the feature lands).
WindowsTerminal
Windows Terminal — ANSI + OSC 8 (Sixel since 1.22 beta).
Implementations
Sourceimpl TerminalProgram
impl TerminalProgram
Sourcepub fn detect() -> Self
pub fn detect() -> Self
Attempt to detect the terminal program mdcat is running on.
Environment variables are consulted in the following priority order:
$TERM(most reliable — it propagates acrosssudo/ssh)$TERM_PROGRAM- Terminal-specific markers:
$WT_SESSION(Windows Terminal),$KONSOLE_VERSION,$TERMINAL_EMULATOR(Contour),$TERMINOLOGY.
Falls back to TerminalProgram::Ansi when no signal is found.
Sourcepub fn capabilities(self) -> TerminalCapabilities
pub fn capabilities(self) -> TerminalCapabilities
Get the capabilities of this terminal emulator.